@@ -5,6 +5,8 @@ from PublicNode import PublicNode
 from LTO.Accounts.AccountFactoryED25519 import AccountED25519
 import string
 import random
+from LTO.Transactions.Sponsorship import Sponsorship
+from LTO.Transactions.CancelSponsorship import CancelSponsorship
 from time import time
 
 def random_string(length=16):
@@ -16,21 +18,14 @@ alice = AccountED25519('T').createFromSeed(aliceSeed)
 bobSeed= 'home visit certain universe adjust thing estate pyramid age puzzle update ensure fatal crucial hat'
 bob = AccountED25519('T').createFromSeed(bobSeed)
 anchor = random_string()
-anchor = '3yMApqCuCjXDWPrbjfR5mjCPTHqFG8Pux1TxQrEM35jj'
 
 address = '3N6MFpSbbzTozDcfkTUT5zZ2sNbJKFyRtRj'
 account = AccountED25519('T').createFromSeed('cool strike recall mother true topic road bright nature dilemma glide shift return mesh strategy')
 
-#transaction = RevokeAssociation(recipient=address, associationType=10)
-#transaction = Association(recipient=bob.address, associationType=3434, anchor=anchor)
-transaction = Association(recipient=address, associationType=7, anchor='fkjnrefkjenr')
-#transaction = Anchor(anchor)
+
+
+transaction = CancelSponsorship(recipient='3N6MFpSbbzTozDcfkTUT5zZ2sNbJKFyRtRj')
 transaction.signWith(account)
-transaction.broadcastTo(node)
-
-
-
-
-
+print(transaction.broadcastTo(node))
 
 
